@@ -2,6 +2,20 @@ library(vpc)
 library(testit)
 Sys.setenv("R_TESTS" = "")
 
+## Test for bug AR 20171025 column name simulation dataset
+test <- vpc::rtte_sim_nm[1:200000,]
+test$bla <- test$t
+test$t <- NULL
+obj <- vpc_tte(sim = test,  # stratified for covariate and study arm
+               obs = vpc::rtte_obs_nm, 
+               rtte = FALSE,
+               sim_cols = list(dv = "dv", idv = "bla"), 
+               obs_cols = list(idv = "t"),
+               labeller = ggplot2::label_both)
+
+assert("vpc_tte no stratification succeeded","ggplot" %in% class(obj))
+
+
 obj <- vpc_tte(sim = vpc::rtte_sim_nm[1:200000,],  # stratified for covariate and study arm
                obs = vpc::rtte_obs_nm, 
                stratify = c("sex","drug"), 
